@@ -1,18 +1,51 @@
-from typing import Optional
+from typing import Optional, Callable
 from time import sleep
+from pathlib import Path
+from functools import partial
 import logging
+import sys
 
 from mpris_server.server import Server
 
 from .base import get_chromecast, Seconds, get_chromecast_via_host, \
   NoChromecastFoundException, LOG_LEVEL, get_chromecast_via_uuid, \
-  DEFAULT_RETRY_WAIT
+  DEFAULT_RETRY_WAIT, NoChromecastFoundException, RC_NO_CHROMECAST, \
+  DATA_DIR, NAME, RC_NOT_RUNNING, PID, NO_DEVICE, DEFAULT_WAIT
 from .adapter import ChromecastAdapter
 from .listeners import register_mpris_adapter
 
 
-DEFAULT_WAIT: Seconds = 30
-NO_DEVICE = 'Device'
+FuncMaybe = Optional[Callable]
+
+
+def set_log_level(level: str = LOG_LEVEL):
+  level = level.upper()
+  logging.basicConfig(level=level)
+
+
+def run_safe(
+  name: Optional[str],
+  host: Optional[str],
+  uuid: Optional[str],
+  wait: Optional[float],
+  retry_wait: Optional[float],
+  icon: bool,
+  log_level: str
+):
+  try:
+    run_server(
+      name,
+      host,
+      uuid,
+      wait,
+      retry_wait,
+      icon,
+      log_level
+    )
+
+  except NoChromecastFoundException as e:
+    logging.warning(f"Device {e} not found")
+    sys.exit(RC_NO_CHROMECAST)
 
 
 def create_adapters_and_server(
@@ -77,7 +110,7 @@ def run_server(
   icon: bool = False,
   log_level: str = LOG_LEVEL
 ):
-  logging.basicConfig(level=log_level.upper())
+  set_log_level(log_level)
   mpris = retry_until_found(name, host, uuid, wait, retry_wait)
 
   if mpris and icon:
